All of lore.kernel.org
 help / color / mirror / Atom feed
From: Malcolm Priestley <tvboxspy@gmail.com>
To: gregkh@linuxfoundation.org
Cc: linux-wireless@vger.kernel.org, Malcolm Priestley <tvboxspy@gmail.com>
Subject: [PATCH 02/12] staging: vt6656: rename device_init_registers to vnt_init_registers
Date: Fri, 25 Jul 2014 20:51:46 +0100	[thread overview]
Message-ID: <1406317916-21884-2-git-send-email-tvboxspy@gmail.com> (raw)
In-Reply-To: <1406317916-21884-1-git-send-email-tvboxspy@gmail.com>

changing device to vnt

Signed-off-by: Malcolm Priestley <tvboxspy@gmail.com>
---
 drivers/staging/vt6656/main_usb.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/vt6656/main_usb.c b/drivers/staging/vt6656/main_usb.c
index 7e8551f..51fad26 100644
--- a/drivers/staging/vt6656/main_usb.c
+++ b/drivers/staging/vt6656/main_usb.c
@@ -37,7 +37,7 @@
  *   device_free_tx_bufs - free tx buffer function
  *   device_dma0_tx_80211- tx 802.11 frame via dma0
  *   device_dma0_xmit- tx PS buffered frame via dma0
  *   device_init_registers- initial MAC & BBP & RF internal registers.
  *   device_init_rings- initial tx/rx ring buffer
  *   device_init_defrag_cb- initial & allocate de-fragement buffer.
  *   device_tx_srv- tx interrupt service function
@@ -131,7 +131,7 @@ static void vnt_set_options(struct vnt_private *priv)
 /*
  * initialization of MAC & BBP registers
  */
-static int device_init_registers(struct vnt_private *priv)
+static int vnt_init_registers(struct vnt_private *priv)
 {
 	struct vnt_cmd_card_init *init_cmd = &priv->init_command;
 	struct vnt_rsp_card_init *init_rsp = &priv->init_response;
@@ -553,7 +553,7 @@ static int vnt_start(struct ieee80211_hw *hw)
 
 	clear_bit(DEVICE_FLAGS_DISCONNECTED, &priv->flags);
 
-	if (device_init_registers(priv) == false) {
+	if (vnt_init_registers(priv) == false) {
 		dev_dbg(&priv->usb->dev, " init register fail\n");
 		goto free_all;
 	}
@@ -954,7 +954,7 @@ static const struct ieee80211_ops vnt_mac_ops = {
 int vnt_init(struct vnt_private *priv)
 {
 
-	if (!(device_init_registers(priv)))
+	if (!(vnt_init_registers(priv)))
 		return -EAGAIN;
 
 	SET_IEEE80211_PERM_ADDR(priv->hw, priv->permanent_net_addr);
@@ -37,7 +37,7 @@
  *   device_dma0_tx_80211- tx 802.11 frame via dma0
  *   device_dma0_xmit- tx PS buffered frame via dma0
- *   device_init_registers- initial MAC & BBP & RF internal registers.
+ *   vnt_init_registers- initial MAC & BBP & RF internal registers.
  *   device_init_rings- initial tx/rx ring buffer
  *   device_init_defrag_cb- initial & allocate de-fragement buffer.
-- 
2.0.1


  reply	other threads:[~2014-07-25 19:52 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2014-07-25 19:51 [PATCH 01/12] staging: vt6656: rename device_set_options to vnt_set_options Malcolm Priestley
2014-07-25 19:51 ` Malcolm Priestley [this message]
2014-07-25 19:51 ` [PATCH 03/12] staging: vt6656: rename device_free_tx_bufs to vnt_free_tx_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 04/12] staging: vt6656: rename device_free_rx_bufs to vnt_free_rx_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 05/12] staging: vt6656: rename device_free_int_bufs to vnt_free_int_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 06/12] staging: vt6656: rename device_alloc_bufs to vnt_alloc_bufs Malcolm Priestley
2014-07-25 19:51 ` [PATCH 07/12] staging: vt6656: main_usb.c remove comments to functions nolonger present Malcolm Priestley
2014-07-25 19:51 ` [PATCH 08/12] staging: vt6656: change driver version to mac80211 Malcolm Priestley
2014-07-25 19:51 ` [PATCH 09/12] staging: vt6656: main_usb.c remove return from void functions Malcolm Priestley
2014-07-25 19:51 ` [PATCH 10/12] staging: vt6656: remove return from all " Malcolm Priestley
2014-07-25 19:51 ` [PATCH 11/12] staging: vt6656: remove comments of old functions nolonger present Malcolm Priestley
2014-07-25 19:51 ` [PATCH 12/12] staging: vt6656: rf.h clean up comments Malcolm Priestley

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1406317916-21884-2-git-send-email-tvboxspy@gmail.com \
    --to=tvboxspy@gmail.com \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-wireless@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.